#
# spec file for package converseen
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           converseen
Version:        0.9.11.1
Release:        1.2
Summary:        Batch Image Conversion Tool
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Convertors
URL:            https://converseen.fasterland.net/
Source0:        https://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.bz2
BuildRequires:  ImageMagick
BuildRequires:  cmake
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(Magick++)
BuildRequires:  pkgconfig(MagickCore)
BuildRequires:  pkgconfig(MagickWand)
Recommends:     %{name}-lang

%description
Converseen is a batch image conversion tool. Converseen allows you
to convert images in more than 100 different formats.

With converseen you can:
- Carry out a single or a multiple conversion.
- Resize one or more images.
- Compress images for your web pages.
- Rotate and flip images.
- Rename a bunch of images using a progressive number or a prefix/suffix.
- Selecting a resampling filter to resize images.

%lang_package

%prep
%setup -q
chmod -x README.md COPYING

%build
%cmake
%cmake_build

%install
# Create desktop file because the original one is incorrect.
cat > res/net.fasterland.%{name}.desktop << EOF
[Desktop Entry]
Name=Converseen
GenericName=Batch Image Converter
GenericName[it]=Convertitore batch di immagini
GenericName[ru]=Конвертер изображений
Comment=Batch image converter
Comment[it]=Convertitore batch di immagini
Comment[ru]=Преобразование изображений
Exec=converseen
Icon=converseen
Categories=Qt;Graphics;RasterGraphics;
StartupNotify=true
Terminal=false
Type=Application
EOF

%cmake_install
rm -rf %{buildroot}%{_datadir}/kservices5/ 

# strip incorrect sRGB profile
convert res/%{name}.png -strip res/%{name}.png
for size in 256x256 128x128 96x96 64x64 48x48 32x32 22x22 16x16 ; do
    install -dm 0755 \
        %{buildroot}%{_datadir}/icons/hicolor/${size}/apps/
    convert res/%{name}.png -strip -resize ${size} \
        %{buildroot}%{_datadir}/icons/hicolor/${size}/apps/%{name}.png || true
done
%find_lang %{name} --with-qt
%suse_update_desktop_file net.fasterland.%{name}

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/net.fasterland.%{name}.desktop
%{_datadir}/icons/hicolor/*/*/%{name}.*
%{_datadir}/metainfo/%{name}.appdata.xml

%files lang -f %{name}.lang
%dir %{_datadir}/%{name}/
%dir %{_datadir}/%{name}/loc/

%changelog
* Sun Apr 30 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to 0.9.11.1
  * Added decimal values in scaling by percentage
  * Various improvements in the user interface
  * Various Bugfixes
- Changes in 0.9.11.0
  * Now, it’s possible to attempt to process corrupted images
  * Updated Turkish Translation
  * Updated Italian translation
  * Various Bugfixes
- Changes in 0.9.10.1
  * Fixed random crash that may happen when images are removed
    from the list
  * Updated Russian translation
  * Various Bugfixes
- Changes in 0.9.10.0
  * Added WebP support for quality, compression, etc
  * Added a feature to remove metadata when images are processed
  * Fixed a bug that inhibits the overwrite feature when the
    Rename option is checked
  * Various Bugfixes
- Changes in 0.9.9.8
  * Updated Russian, Turkish and Italian translations
  * Various Bugfixes
- Changes in 0.9.9.7
  * Added hicolor icons on Linux
  * The program is now adapted to be distributed as AppImage
  * The program is now adapted to be distributed as Snap Package
  * Various Bugfixes
- Changes in 0.9.9.6
  * Improved quality and compression settings for JPEG and PNG
    formats
  * Various Bugfixes
* Thu May  5 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.9.9.5
  * Added scaling/support for HiDPI Displays
  * Various Bugfixes
  * Additional changes included in version 0.9.9.4
  * Fixed Overwrite Option
  * Updated Some Languages
  * Additional changes included in version 0.9.9.3
  * Added Simplified Chinese Translation
  * Additional changes included in version 0.9.9.2
  * Added PDF conversion instructions
  * Minor Updates
  * Additional changes included in version 0.9.9.1
  * Added JFIF support
  * Fixed settings data location
  * Various Minor Updates
* Mon Mar  8 2021 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 0.9.9.0.
  * Fixed random crash when all images are removed.
  * Some translation updates.
  * Various minor updates.
  * Various bugfixes.
* Tue Feb  4 2020 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 0.9.8.1.
  * Added Swedish translation.
  * Various minor updates.
  * Various bugfixes.
* Mon Nov  4 2019 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 0.9.8.0.
  * Fixed bug with TIF files.
  * Various Minor Updates.
  * Various bugfixes.
* Thu Nov  1 2018 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 0.9.7.2.
  * Updated Japanese Localization.
  * Various bugfixes.
* Mon Oct 15 2018 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 0.9.7.1.
  * Various bugfixes.
- Changes in 0.9.7.
  * Added Ukranian Traslation.
  * Updated Italian Traslation.
  * Removed Flattr links and buttons.
  * Various bugfixes.
* Tue Apr  4 2017 lazy.kent@opensuse.org
- Update to 0.9.6.2.
  * Added Danish Translation.
  * Updated Italian Translation.
  * Various bugfixes.
* Fri Mar 24 2017 pgajdos@suse.com
- Update to 0.9.6.1.
  * Updated French Translation
  * Various bugfixes
* Sat Jan 21 2017 lazy.kent@opensuse.org
- Update to 0.9.6.
  * Added support for ImageMagick 7.
  * Various code improvements.
* Sun Oct  9 2016 lazy.kent@opensuse.org
- Update to 0.9.5.2.
  * Added some generic code fixings.
* Wed Sep 28 2016 lazy.kent@opensuse.org
- Update to 0.9.5.1.
  * Updated French Translation.
  * Updated Appdata file for Linux.
* Wed Aug 31 2016 lazy.kent@opensuse.org
- Update to 0.9.5.
  * Porting to Qt5.
- Use cmake() build dependencies instead of pkgconfig() for Qt5
  devel packages.
* Tue Mar  8 2016 bwiedemann@suse.com
- drop build time from png file to fix build-compare
* Thu Mar 26 2015 lazy.kent@opensuse.org
- Update to 0.9.2.
  * Updates for some translations.
  * Various code optimizations and improvements.
* Fri Mar  6 2015 lazy.kent@opensuse.org
- Update to 0.9.1.
  * Updates dialog is now more user friendly.
  * Various code optimizations and improvements.
* Fri Feb 13 2015 lazy.kent@opensuse.org
- Update to 0.9.0.
  * Various code optimizations and improvements.
  * Some translations has been updated.
* Sun Feb  1 2015 lazy.kent@opensuse.org
- Update to 0.8.6.
  * Fixed crashes when selecting some pictures.
  * Various bugfixes.
- Use %%cmake and %%cmake_install macros.
* Fri Nov 28 2014 lazy.kent@opensuse.org
- Update to 0.8.5.
  * Added option to disable automatic checking for updates.
  * Various bugfixes.
- Remove BuildRequires: appdata-tools.
* Wed Oct  1 2014 lazy.kent@opensuse.org
- Update to 0.8.4.
  * Various bugfixes.
* Sun Aug 31 2014 lazy.kent@opensuse.org
- Update to 0.8.3.
  * Various bugfixes.
* Mon Aug 25 2014 lazy.kent@opensuse.org
- Update to 0.8.2.
  * Fixed a bug with PDF files conversion.
* Sun Aug 17 2014 lazy.kent@opensuse.org
- Update to 0.8.1.
  * Fixed a bug with files with uppercase extensions.
* Sat Aug  2 2014 lazy.kent@opensuse.org
- Update to 0.8.
  * Fixed glitches and artifacts with picture previews.
  * Added important improvements and optimizations to picture
    preview algorithms.
  * Various bugfixes.
- Change URL.
* Mon Jul 21 2014 lazy.kent@opensuse.org
- Update to 0.7.3.
  * Updated Polish translation.
  * Various bugfixes.
* Fri Jul 18 2014 pgajdos@suse.com
- remove +regard-warnings again, as libpng incorrect profile warning
  is ignored in ImageMagick 6.8.9-5 and later
* Fri Jun 27 2014 pgajdos@suse.com
- use +regard-warnings instead of ||true when convert -strip
* Thu Jun 26 2014 pgajdos@suse.com
- fixed build, convert -strip returns false when stripping
  incorrect profile
  http://www.imagemagick.org/discourse-server/viewtopic.php?f=3&t=25809
* Wed May 28 2014 lazy.kent@opensuse.org
- Update to 0.7.2.
  * Added AppData file.
  * Updated German translation.
- Changes in 0.7.1.1.
  * Updated Czech, Japanese and Spanish translations.
- BuldReqires appdata-tools for openSUSE >= 13.2.
* Wed May  7 2014 lazy.kent@opensuse.org
- Update to 0.7.1.
  * Fixed some issues with the settings dialog.
  * Various bugfixes.
* Tue May  6 2014 lazy.kent@opensuse.org
- Update to 0.7.0.
  * Now is possible to convert an entire PDF in a bunch of
    pictures.
  * Now is possible to extract single images from a Windows icon
    (ico) file.
  * Added various code improvements.
* Fri Mar  7 2014 lazy.kent@opensuse.org
- Update to 0.6.8.
  * Update some translations.
  * Various code improvements.
* Wed Feb  5 2014 lazy.kent@opensuse.org
- Update to 0.6.7.
  * Now is possible to resize a bunch of pictures with different
    size keeping the aspect ratio.
  * Added a menu item for bug signalation.
  * Various code improvements.
- Improve description.
- Add BuildRequires: pkgconfig(QtNetwork)
* Tue Nov 19 2013 lazy.kent@opensuse.org
- Update to 0.6.6.
  * Added Japanese translation.
  * Updated Russian Translation.
- Drop converseen-0.6.5-russian.patch (fixed upstream).
* Tue Oct 29 2013 lazy.kent@opensuse.org
- Update to 0.6.5.
  * Various code improvements.
- Add converseen-0.6.5-russian.patch: correct and update Russian
  translation.
* Tue Oct  1 2013 tchvatal@suse.com
- There is no reason to hardcode libnames as they are detected
  properly by itself.
* Tue Jul 23 2013 lazy.kent@opensuse.org
- Update to 0.6.4.
  * Now the "Mantain aspect ratio checkbox" is checked by default.
  * Updated Czech translation.
  * Added Polish translation.
* Tue Jun 25 2013 lazy.kent@opensuse.org
- Correct License tag: GPL-2.0+ -> GPL-3.0+.
* Sat Jun 15 2013 lazy.kent@opensuse.org
- Update to 0.6.3.
  * Fixed some bugs when renaming files.
  * Added social buttons in the about dialog.
  * Various code improvements and optimizations.
- Changes in 0.6.2.
  * Various code improvements and optimizations.
* Fri May  3 2013 lazy.kent@opensuse.org
- Update to 0.6.1.
  * Updated Czech, German and Russian translations.
* Mon Apr 15 2013 lazy.kent@opensuse.org
- Update to 0.6.
  * Improved the preview generation process.
  * Possibility to rotate and flip the images.
  * Now the user can choose to resize images using one of the 16
    interpolation filters.
  * Now the user can rename files using a progressive number.
  * Various improvements on the code.
  * Removed Polish translation.
  * Various bugs fixed.
* Sun Apr 14 2013 lazy.kent@opensuse.org
- Use versioned ImageMagick include directory for openSUSE > 12.3.
* Sun Mar 31 2013 lazy.kent@opensuse.org
- Use quantum depth suffix in library names for openSUSE > 12.3.
* Thu Feb 14 2013 lazy.kent@opensuse.org
- Update to 0.5.3.
  * Now it works with ImageMagick >= 6.8.0.
  * Added Russian translation.
* Mon Nov 12 2012 lazy.kent@opensuse.org
- Update to 0.5.2.
  * Updated the German translation.
* Mon Jul  2 2012 lazy.kent@opensuse.org
- Update to 0.5.1.
  * Fixed a bug with density/resolution settings.
  * Updated translations (Hungarian, Czech, French, Brazilian
    Portuguese, Spanish).
* Tue Jun  5 2012 lazy.kent@opensuse.org
- Update to 0.5.
  * New and highly optimized graphical user interface.
  * Improved thumbnail generation.
  * Possibility to resize different image formats without changing
    the destination formats.
  * Possibility to choose a background color when converting images
    to formats that don't support alpha channel like jpeg files.
  * Possibility to override transparency with an arbitrary color.
  * Improved conversion process.
  * Now, at the end of the conversion process, the destination
    folder(s) can be opened with a click.
  * All the interface attributes are automatically saved.
  * Fixed the bug with dotted filenames.
  * Both tif and tiff formats can be opened.
  * Other GUI improvements.
  * Various bugs fixed.
* Tue Feb 28 2012 lazy.kent@opensuse.org
- Split off language package.
* Sun Feb 26 2012 lazy.kent@opensuse.org
- Use pkgconfig(*) in build dependencies.
- Use make_install macro.
- Remove check for unsupported openSUSE versions.
* Tue Jan 31 2012 lazy.kent@opensuse.org
- Update to 0.4.9.
  * Fixed a bug with special characters.
* Tue Jan 17 2012 lazy.kent@opensuse.org
- Update to 0.4.8.
  * Fixed a bug in picture previewer.
* Fri Dec  9 2011 lazy.kent@opensuse.org
- Update to 0.4.7.
  * Optimized GUI for small screen resolutions (netbooks).
  * Fixed overwriting with upper suffixes.
  * Now the window geometry is saved.
- Use cmake to build the package.
- Updated Description.
* Sun Nov  6 2011 lazy.kent@opensuse.org
- Spec clean up.
* Thu Sep 15 2011 lazy.kent@opensuse.org
- Update to 0.4.6.
  * Fixed a bug with the overwriting option.
-  Update to 0.4.5.
  * Added Turkish translation.
* Wed Aug  3 2011 lazy.kent@opensuse.org
- Update to 0.4.3
  * Fixed overwriting with upper suffixes.
  * Added Spanish (Chile) translation.
- Update to 0.4.2
  * Fixed overwriting dialog when the renaming option is enabled.
- Added qmake optflags.
- Corrected License tag.
- Use full URL for source.
- Use %%icon_theme_cache_post/un macros.
- Added COPYING to docs.
- Don't install service menu for KDE4.
* Wed Mar 16 2011 lazy.kent@opensuse.org
- Update to 0.4.1
  * Improved picture previewer.
  * If the output folder doesn't exists it will be created.
- Build requires hicolor-icon-theme and ImageMagick.
- Install icons of different sizes.
- Don't install icon into pixmaps dir.
* Fri Feb 11 2011 lazy.kent@opensuse.org
- Update to 0.4.
  * Added thread support to image conversions.
  * Added a progress bar into the conversion dialog.
  * Added drag and drop.
  * Improved management of PNG.
  * Fixed various bugs and improved the code.
  * Added Brazilian Portuguese translation.
  * Added German translation.
- License corrected to GPLv2+.
- Install icon into hicolor/64x64/apps.
* Sat Oct 23 2010 lazy.kent.suse@gmail.com
- Update to 0.3.2.
  * Added French translation by Ludovic Troisi.
* Sun Sep 12 2010 lazy.kent.suse@gmail.com
- Update to 0.3.1.
  * Fixed crash when deleting photos.
  * Fixed informations about images on "Dimensions" box.
  * Increased performances for previews.
  * Various code improvements.
* Tue Apr 13 2010 lazy.kent.suse@gmail.com
- Update to 0.3.
  * Improved image resizing options. Now it's possible to resize
    images by percentage or pixel.
  * Czech translation by Pavel Fric.
* Tue Dec 29 2009 lazy.kent.suse@gmail.com
- Update to 0.2.1.
  * Fixed and improved file dialog.
  * Hungarian translation by Charles Barcza.
* Fri Nov 20 2009 lazy.kent.suse@gmail.com
- Initial package created - 0.2.
